@@ -5,9 +5,9 @@ use warnings;
 use Carp qw{ croak };
 use utf8;
 
-use Exporter::Shiny qw/show_graph/;
+use Exporter::Shiny qw/show_graph vspark/;
 
-our $VERSION = 0.32;
+our $VERSION = 0.33;
 
 sub _bar {
     my (%args) = @_;
@@ -91,7 +91,7 @@ sub _term_width {
     require Term::ReadKey;
     my ($cols) = Term::ReadKey::GetTerminalSize(*STDOUT);
     return 80    if !$cols;
-    return $cols if  $columns eq 'max';
+    return $cols if  $columns && $columns eq 'max';
     return 80    if $cols > 80;
     return $cols;
 }
@@ -169,6 +169,7 @@ your terminal width or 80 characters -- whichever is smaller.  Set 'columns' to
 =head1 AUTHOR
 
 Eric Johnson (kablamo)
+
 Gil Gonçalves <lurst@cpan.org> (original author)
 
 =head1 SEE ALSO
